==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiGui/QAbstractUndoItem_shell.cpp <==
#include "QAbstractUndoItem_shell.h"
#include <QtJambi/Cast>

void deleter_QAbstractUndoItem(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAbstractUndoItem")
    QAbstractUndoItem *_ptr = reinterpret_cast<QAbstractUndoItem *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAbstractUndoItem_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAbstractUndoItem_shell) ); }

jmethodID QAbstractUndoItem_shell::__shell_javaMethod(int pos) const { return QAbstractUndoItem_shell::__shell()->javaMethod(typeid(QAbstractUndoItem), pos); }

// emitting (writeShellConstructor)
QAbstractUndoItem_shell::QAbstractUndoItem_shell()
    : QAbstractUndoItem()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAbstractUndoItem::QAbstractUndoItem_shell()", QAbstractUndoItem_shell::__shell())
    QAbstractUndoItem_shell::__shell()->constructed(typeid(QAbstractUndoItem));
}

// emitting (writeShellDestructor)
QAbstractUndoItem_shell::~QAbstractUndoItem_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAbstractUndoItem::~QAbstractUndoItem()", QAbstractUndoItem_shell::__shell())
    QAbstractUndoItem_shell::__shell()->destructed(typeid(QAbstractUndoItem));
}

void QAbstractUndoItem_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAbstractUndoItem_shell*>(ptr)->QAbstractUndoItem_shell::__shell()->tryDeleteShell(typeid(QAbstractUndoItem));
}

// emitting Virtual overrides (virtualFunctions)
void QAbstractUndoItem_shell::redo()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractUndoItem::", QAbstractUndoItem_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractUndoItem_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractUndoItem_shell::__shell()->warnForMethod("QAbstractUndoItem::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractUndoItem::");
            } QTJAMBI_TRY_END
        }
    }
}

void QAbstractUndoItem_shell::undo()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractUndoItem::", QAbstractUndoItem_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractUndoItem_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractUndoItem_shell::__shell()->warnForMethod("QAbstractUndoItem::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractUndoItem::");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QAbstractUndoItem_access::__qt_redo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAbstractUndoItem::redo()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAbstractUndoItem::redo().";
    } else {
        redo();
    }
}

void QAbstractUndoItem_access::__qt_undo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAbstractUndoItem::undo()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAbstractUndoItem::undo().";
    } else {
        undo();
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QAbstractUndoItem_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QAbstractUndoItem *__qt_this = new(__qtjambi_ptr) QAbstractUndoItem_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QAbstractUndoItem_shell
void __qt_destruct_QAbstractUndoItem(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractUndoItem")
    reinterpret_cast<QAbstractUndoItem_shell*>(ptr)->~QAbstractUndoItem_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAbstractUndoItem::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractUndoItem_00024Impl_initialize_1native__Lio_qt_gui_QAbstractUndoItem_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractUndoItem::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractUndoItem_0, sizeof(QAbstractUndoItem_shell), typeid(QAbstractUndoItem), true, &deleter_QAbstractUndoItem, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAbstractUndoItem::redo()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractUndoItem_00024Impl_00024ConcreteWrapper_redo_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QAbstractUndoItem *__qt_this = QtJambiAPI::interfaceFromNativeId<QAbstractUndoItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractUndoItem::redo()", __qt_this)
        static_cast<QAbstractUndoItem_access*>(__qt_this)->__qt_redo(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAbstractUndoItem::undo()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractUndoItem_00024Impl_00024ConcreteWrapper_undo_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QAbstractUndoItem *__qt_this = QtJambiAPI::interfaceFromNativeId<QAbstractUndoItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractUndoItem::undo()", __qt_this)
        static_cast<QAbstractUndoItem_access*>(__qt_this)->__qt_undo(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAbstractUndoItem(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QAbstractUndoItem>("QAbstractUndoItem", "io/qt/gui/QAbstractUndoItem");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "redo", "()V", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "undo", "()V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QAbstractUndoItem, {
        ConstructorInfo(&__qt_construct_QAbstractUndoItem_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAbstractUndoItem);
    registerSizeOfShell(typeId, sizeof(QAbstractUndoItem_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QAbstractUndoItem* _object = dynamic_cast<QAbstractUndoItem*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QAbstractUndoItem *object = reinterpret_cast<QAbstractUndoItem *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QAbstractUndoItem *object = reinterpret_cast<const QAbstractUndoItem *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiGui/QAbstractUndoItem_shell.cpp <==
#include "QAbstractUndoItem_shell.h"
#include <QtJambi/Cast>

void deleter_QAbstractUndoItem(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAbstractUndoItem")
    QAbstractUndoItem *_ptr = reinterpret_cast<QAbstractUndoItem *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAbstractUndoItem_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAbstractUndoItem_shell) ); }

jmethodID QAbstractUndoItem_oshell::__shell_javaMethod(int pos) const { return QAbstractUndoItem_shell::__shell()->javaMethod(typeid(QAbstractUndoItem), pos); }

// emitting (writeShellDestructor)
QAbstractUndoItem_shell::~QAbstractUndoItem_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAbstractUndoItem::~QAbstractUndoItem()", this)
    QAbstractUndoItem_shell::__shell()->destructed(typeid(QAbstractUndoItem));
}

// emitting (writeShellConstructor)
QAbstractUndoItem_shell::QAbstractUndoItem_shell()
    : QAbstractUndoItem()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAbstractUndoItem::QAbstractUndoItem_shell()", this)
    QAbstractUndoItem_shell::__shell()->constructed(typeid(QAbstractUndoItem));
}

void QAbstractUndoItem_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAbstractUndoItem_oshell*>(ptr)->QAbstractUndoItem_oshell::__shell()->tryDeleteShell(typeid(QAbstractUndoItem));
}

// emitting Virtual overrides (virtualFunctions)
void QAbstractUndoItem_oshell::redo()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractUndoItem::redo()", this)
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractUndoItem_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractUndoItem_shell::__shell()->warnForMethod("QAbstractUndoItem::redo()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractUndoItem::redo()");
            } QTJAMBI_TRY_END
        }
    }
}

void QAbstractUndoItem_oshell::undo()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractUndoItem::undo()", this)
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractUndoItem_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractUndoItem_shell::__shell()->warnForMethod("QAbstractUndoItem::undo()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractUndoItem::undo()");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QAbstractUndoItem_access::__qt_redo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAbstractUndoItem::redo()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAbstractUndoItem::redo().";
    } else {
        redo();
    }
}

void QAbstractUndoItem_access::__qt_undo(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAbstractUndoItem::undo()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAbstractUndoItem::undo().";
    } else {
        undo();
    }
}

// emitting (writeConstructors)
// new QAbstractUndoItem()
void __qt_construct_QAbstractUndoItem(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAbstractUndoItem()")
    Q_UNUSED(__java_arguments)
    QAbstractUndoItem *__qt_this = new(__qtjambi_ptr) QAbstractUndoItem_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QAbstractUndoItem::QAbstractUndoItem()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractUndoItem_00024Impl_initialize_1native__Lio_qt_gui_QAbstractUndoItem_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAbstractUndoItem::QAbstractUndoItem()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAbstractUndoItem, sizeof(QAbstractUndoItem_shell), typeid(QAbstractUndoItem), 0, true, &deleter_QAbstractUndoItem, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAbstractUndoItem_shell
void __qt_destruct_QAbstractUndoItem(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractUndoItem")
    reinterpret_cast<QAbstractUndoItem_shell*>(ptr)->~QAbstractUndoItem_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAbstractUndoItem::redo()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractUndoItem_00024Impl_00024ConcreteWrapper_redo_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QAbstractUndoItem *__qt_this = QtJambiAPI::interfaceFromNativeId<QAbstractUndoItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractUndoItem::redo()", __this_nativeId)
        static_cast<QAbstractUndoItem_access*>(__qt_this)->__qt_redo(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAbstractUndoItem::undo()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractUndoItem_00024Impl_00024ConcreteWrapper_undo_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    QTJAMBI_TRY {
        QAbstractUndoItem *__qt_this = QtJambiAPI::interfaceFromNativeId<QAbstractUndoItem>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractUndoItem::undo()", __this_nativeId)
        static_cast<QAbstractUndoItem_access*>(__qt_this)->__qt_undo(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAbstractUndoItem(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QAbstractUndoItem>("QAbstractUndoItem", "io/qt/gui/QAbstractUndoItem");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "redo", "()V", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "undo", "()V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QAbstractUndoItem, {
        ConstructorInfo(&__qt_construct_QAbstractUndoItem, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAbstractUndoItem);
    registerSizeOfShell(typeId, sizeof(QAbstractUndoItem_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QAbstractUndoItem* _object = dynamic_cast<QAbstractUndoItem*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QAbstractUndoItem *object = reinterpret_cast<QAbstractUndoItem *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QAbstractUndoItem *object = reinterpret_cast<const QAbstractUndoItem *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
